@@ -2,11 +2,11 @@ package DateTimeX::Format::Excel;
 BEGIN {
   $DateTimeX::Format::Excel::AUTHORITY = 'cpan:JANDREW';
 }
-use	version; our $VERSION = qv("v0.12.6");
+use	version; our $VERSION = qv("v0.12.8");
 use	5.010;
 use	strict;
 use	warnings;
-use	Moose;
+use	Moose 2.1213;
 use	MooseX::StrictConstructor;
 use	MooseX::HasDefaults::RO;
 use	DateTime;
